#
# spec file for package gnome-browser-connector
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-browser-connector
Version:        42.1
Release:        4.1
Summary:        GNOME Shell integration for Chrome Extension compatible browsers
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Web/Browsers
URL:            https://wiki.gnome.org/action/show/Projects/GnomeShellIntegration
Source:         https://download.gnome.org/sources/%{name}/42/%{name}-%{version}.tar.xz
# PATCH-FIX-SLE python36.patch bsc#1223902 yfjiang@suse.com  -- Patch to support python 3.6 on SLE/Leap 15.6.
Patch0:         python36.patch

BuildRequires:  hicolor-icon-theme
BuildRequires:  meson
BuildRequires:  python3-gobject
Provides:       chrome-gnome-shell = %{version}
Obsoletes:      chrome-gnome-shell < %{version}
# Auto-install when the user uses GNOME Shell and any of the (known) supported browsers
Supplements:    (gnome-shell and MozillaFirefox)
Supplements:    (gnome-shell and chromium)
Supplements:    (gnome-shell and google-chrome-stable)
Supplements:    (gnome-shell and opera)

%description
Browser extension for Google Chrome/Chromium, Firefox, Vivaldi, Opera (and other
Browser Extension, Chrome Extension or WebExtensions capable browsers) and native
host messaging connector that provides integration with GNOME Shell and the
corresponding extensions repository https://extensions.gnome.org.

%prep
%setup -q
%if 0%{?sle_version} && 0%{?sle_version} < 160000
%autopatch -p1
%endif

%build
%meson
%meson_build

%install
%meson_install
%python3_fix_shebang

%files
%license LICENSE
%doc README.md NEWS
%config %{_sysconfdir}/chromium/
%config %{_sysconfdir}/opt/chrome/
%{_bindir}/gnome-browser-connector
%{_bindir}/gnome-browser-connector-host
%{python3_sitelib}/gnome_browser_connector/
%{_libdir}/mozilla/
%{_datadir}/applications/org.gnome.BrowserConnector.desktop
%dir %{_datadir}/dbus-1
%dir %{_datadir}/dbus-1/services
%{_datadir}/dbus-1/services/org.gnome.BrowserConnector.service
%{_datadir}/icons/hicolor/*/apps/*.png

%changelog
* Mon May  6 2024 Yifan Jiang <yfjiang@suse.com>
- Patch to support python 3.6 on SLE/Leap 15.6 (bsc#1223902):
  python36.patch.
* Mon Apr 29 2024 pgajdos@suse.com
- remove dependency on /usr/bin/python3 using
  %%python3_fix_shebang macro, [bsc#1212476]
* Sun Sep 11 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Use new upstream source url.
* Fri Sep  9 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 42.1:
  + Added detected python path in scripts shebang.
  + Restored compatibility with Python 3.8.
  + Fix errors in `get_variant` helper that leads to connector
    crash.
  + Fixed build system error when python dependencies are missing.
- Update Source tag to reflect new home.
- Drop hashbang fixes to python scripts: no longer required.
* Sun Aug 21 2022 Atri Bhattacharya <badshah400@gmail.com>
- Initial package (renamed from chrome-gnome-shell).
